Client
======

The ``VergeClient`` class is the main entry point for interacting with VergeOS.

VergeClient
-----------

.. autoclass:: pyvergeos.VergeClient
   :members:
   :undoc-members:
   :show-inheritance:

Connection
----------

.. automodule:: pyvergeos.connection
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:
